@@ -5,6 +5,8 @@ require "shellwords"
 require "packager/product_patterns"
 require "y2packager/resolvable"
 require "y2packager/repository"
+require "uri"
+require "yast2/rel_url"
 
 # Yast namespace
 module Yast
@@ -26,10 +28,9 @@ module Yast
       # SLE12 HA GEO is now included in SLE15 HA
       "sle-ha-geo"                        => ["sle-ha"],
       "SUSE_SLES_SAP"                     => ["SLES_SAP"],
-      # SLES-12 with HPC module can be replaced by SLE_HPC-15
-      "SLES"                              => ["SLE_HPC"],
-      # this is an internal product so far...
-      "SLE-HPC"                           => ["SLE_HPC"],
+      # SLE HPC is not a base product anymore, it is SLES (+ HPC module) now
+      "SLE-HPC"                           => ["SLES"],
+      "SLE_HPC"                           => ["SLES"],
       # SMT is now integrated into the base SLES
       "sle-smt"                           => ["SLES"],
       # Live patching is a module now (bsc#1074154)
@@ -46,11 +47,21 @@ module Yast
       # the IBM tools have been renamed in SLE12->SLE15 upgrade
       "ibm-dlpar-utils"                   => ["ibm-power-tools"]
 
-      # NOTE: if you change anything here then check
-      # https://github.com/yast/yast-packager/blob/master/src/lib/y2packager/product_upgrade.rb#L27
-      # maybe it needs an update as well...
+      # NOTE: if you change anything here then check the MAPPING value
+      # in the src/lib/y2packager/product_upgrade.rb file, maybe it needs an update as well...
     }.freeze
 
+    private_constant :DEFAULT_PRODUCT_RENAMES
+
+    # flag for using old or new product mapping, not used in SLE15-SP6+
+    attr_accessor :new_renames
+
+    def default_product_renames
+      # no special handling, the product renames is a static map in SLE15-SP6+,
+      # in SLE15-SP5 it is dynamic depending on the installed version
+      DEFAULT_PRODUCT_RENAMES
+    end
+
     # @return [Hash] Product renames added externally through the #add_rename method
     attr_accessor :external_product_renames
     private :external_product_renames, :external_product_renames=
@@ -389,23 +400,49 @@ module Yast
     end
 
     # Returns an absolute URL from base + relative url.
-    # Relative URL needs to start with 'reulrl://' othewise
-    # it is not considered being relative and it's returned
-    # as it is (just the relative_url parameter).
+    #
+    # Relative URL needs to start with 'relurl://' or 'repo:/', otherwise it
+    # is not considered being relative and it's returned as it is (just the
+    # relative_url parameter).
+    #
+    # 'repo' URLs are resolved relative to the installation medium, not base_url.
     #
     # @param [String] base_url
-    # @param [String] url URL relative to the base
+    # @param [String] url URL relative to base_url resp. installation medium
     #
     # @example
     #   AddOnProduct::GetAbsoluteURL (
     #     "http://www.example.org/some%20dir/another%20dir",
     #     "relurl://../AnotherProduct/"
     #   ) -> "http://www.example.org/some%20dir/AnotherProduct/"
+    #
     #   AddOnProduct::GetAbsoluteURL (
-    #     "username:password@ftp://www.example.org/dir/",
+    #     "ftp://username:password@www.example.org/dir/",
     #     "relurl://./Product_CD1/"
-    #   ) -> "username:password@ftp://www.example.org/dir/Product_CD1/"
+    #   ) -> "ftp://username:password@www.example.org/dir/Product_CD1/"
+    #
+    #   with /etc/install.inf containing the line 'ZyppRepoURL: hd:/?device=/dev/sda'
+    #   AddOnProduct::GetAbsoluteURL (
+    #     "ftp://username:password@www.example.org/dir/",
+    #     "repo:/Product_CD1"
+    #   ) -> "hd:/Product_CD1?device=/dev/sda"
     def GetAbsoluteURL(base_url, url)
+      url_parsed = URI(url)
+
+      if url_parsed.scheme == "repo"
+        base_url = InstURL.installInf2Url("")
+        if base_url.empty?
+          log.error "no ZyppRepoURL in /etc/install.inf"
+        else
+          rel_url = "relurl:" + url_parsed.path
+          url = Yast2::RelURL.from_installation_repository(rel_url).absolute_url.to_s
+          log.info("base url + relative path: #{URL.HidePassword(base_url)} + #{url_parsed.path}")
+          log.info("absolute url: #{URL.HidePassword(url)}")
+        end
+
+        return url
+      end
+
       if !Builtins.regexpmatch(url, "^relurl://")
         Builtins.y2debug("Not a relative URL: %1", URL.HidePassword(url))
         return url
@@ -1988,7 +2025,7 @@ module Yast
 
       # handle the product renames, if a renamed product was installed
       # replace it with the new product so the new product is preselected
-      DEFAULT_PRODUCT_RENAMES.each do |k, v|
+      default_product_renames.each do |k, v|
         next unless installed_addons.include?(k)
 
         installed_addons.delete(k)
@@ -2079,12 +2116,12 @@ module Yast
 
     # Determine whether a product rename is included in the fallback map
     #
-    # @see DEFAULT_PRODUCT_RENAMES
+    # @see default_product_renames
     # @see #renamed_at?
     def renamed_by_default?(old_name, new_name)
       log.info "Search #{old_name} -> #{new_name} rename in default map: " \
-               "#{DEFAULT_PRODUCT_RENAMES.inspect}"
-      renamed_at?(DEFAULT_PRODUCT_RENAMES, old_name, new_name)
+               "#{default_product_renames.inspect}"
+      renamed_at?(default_product_renames, old_name, new_name)
     end
 
     # Determine whether a product rename is present on a given hash
